=======
History
=======

1.1.2 (2022-03-25)
------------------

* Add `ignoreconflicting` flag to djloaddata command to ignore rows that fails with `IntegrityError`

1.1.1 (2022-01-21)
------------------

* Add support for circular and self referential data

1.0.1 (2022-01-09)
------------------

* Initial release.
